<?php

drupal_add_css(path_to_theme() . '/style-ie8.css', array('group' => CSS_THEME, 'browsers' => array('IE' => 'IE 8', '!IE' => FALSE), 'preprocess' => FALSE));
drupal_add_css(path_to_theme() . '/style-ie67.css', array('group' => CSS_THEME, 'browsers' => array('IE' => 'lte IE 7', '!IE' => FALSE), 'preprocess' => FALSE));

function plural_form($number, $after) {
  $cases = array (2, 0, 1, 1, 1, 2);
  echo $after[ ($number%100>4 && $number%100<20)? 2: $cases[min($number%10, 5)] ];
}

function check_active($tree, $current){
	foreach ($tree as $menuItem) {
		if (isset($menuItem['below']) && is_array($menuItem['below']) && !empty($menuItem['below'])) {
			$menuItem['link']['in_active_trail'] = check_active($menuItem['below'], $current);
		} else 
			if (isset($menuItem['link']['link_path']) && $menuItem['link']['link_path'] == $current){
				return 1;
			}
	}
	return false;
}

function add_active_trail($tree) {
	$current = current_path();
	$newTree = array();
	foreach ($tree as $k=>$menuItem) {
		if (isset($menuItem['below']) && is_array($menuItem['below']) && !empty($menuItem['below'])) {
			$menuItem['link']['in_active_trail'] = check_active($menuItem['below'], $current);
		} else if (isset($menuItem['link']['link_path']) && $menuItem['link']['link_path'] == $current)
			$menuItem['link']['link_path'] = 1;
		$newTree[$k] = $menuItem;
	}
	return $newTree;
}

function modern_menu_link(array $variables) {
  $element = $variables['element'];
  $sub_menu = '';
  if ($element['#below']) {
    $sub_menu = drupal_render($element['#below']);
  }
  
  $element['#attributes']['class'][] = 'level-' . $element['#original_link']['depth'];
  
  $output = l($element['#title'], $element['#href'], $element['#localized_options']);
  return '<li' . drupal_attributes($element['#attributes']) . '>' . $output . $sub_menu . "</li>\n";
}
  
function modern_breadcrumb($variables) {
  $sep = ' / ';
  if (count($variables['breadcrumb']) > 1) {
    return implode($sep, $variables['breadcrumb']);
  }
}

function modern_process_page(&$vars) {
  $vars['primary_local_tasks'] = menu_primary_local_tasks();
  $vars['secondary_local_tasks'] = menu_secondary_local_tasks();
}


function modern_form_element($variables) {
  
  $element =& $variables['element'];

  // This function is invoked as theme wrapper, but the rendered form element
  // may not necessarily have been processed by form_builder().
  $element += array(
    '#title_display' => 'before',
  );

  // Add element #id for #type 'item'.
  if (isset($element['#markup']) && !empty($element['#id'])) {
    $attributes['id'] = $element['#id'];
  }

  // Add element's #type and #name as class to aid with JS/CSS selectors.
  $attributes['class'] = array(
    'form-item',
  );
  if (!empty($element['#type'])) {
    $attributes['class'][] = 'form-type-' . strtr($element['#type'], '_', '-');
  }
  if (!empty($element['#name'])) {
    $attributes['class'][] = 'form-item-' . strtr($element['#name'], array(
      ' ' => '-',
      '_' => '-',
      '[' => '-',
      ']' => '',
    ));
  }

  // Add a class for disabled elements to facilitate cross-browser styling.
  if (!empty($element['#attributes']['disabled'])) {
    $attributes['class'][] = 'form-disabled';
  }
  $output = '<div' . drupal_attributes($attributes) . '>' . "\n";

  // If #title is not set, we don't display any label or required marker.
  if (!isset($element['#title'])) {
    $element['#title_display'] = 'none';
  }

  if (!empty($element['#type']) and ($element['#type'] == 'select')) {
	if ($element['#multiple'] == '1') {
	  $prefix = '<div class="form-select-multiple-wrapper">';
	  $suffix = '</div>';
	} else {
	  $prefix = '<span class="form-select-wrapper">';
	  $suffix = '</span>';	  
	}	
  } else {
	$prefix = isset($element['#field_prefix']) ? '<span class="field-prefix">' . $element['#field_prefix'] . '</span> ' : '';
	$suffix = isset($element['#field_suffix']) ? ' <span class="field-suffix">' . $element['#field_suffix'] . '</span>' : '';
  }
	
  switch ($element['#title_display']) {
    case 'before':
    case 'invisible':
      $output .= ' ' . theme('form_element_label', $variables);
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;
    case 'after':
      $output .= ' ' . $prefix . $element['#children'] . $suffix;
      $output .= ' ' . theme('form_element_label', $variables) . "\n";
      break;
    case 'none':
    case 'attribute':

      // Output no label and no required marker, only the children.
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;
  }
  if (!empty($element['#description'])) {
    $output .= '<div class="description">' . $element['#description'] . "</div>\n";
  }
  $output .= "</div>\n";
  return $output;
  
}

function modern_menu_alter(&$items) {
  $items['user/%user/edit']['access arguments'] = array('administer users');
  $items['user/%user/edit']['access callback'] = 'user_access';
}

function modern_form_alter(&$form, $form_state, $form_id) {
  global $user;

  $form['field_bitrix_id']['#access'] = 0;
  unset($form['metatags']['und']['basic']['#description']);
  unset($form['metatags']['ru']['basic']['#description']);
  hide($form['locale']);
  
  if (isset($form['path']['pathauto'])) unset($form['path']);
  
  if ($form_id === 'user_profile_form') {
	if (!in_array('administrator', $user->roles)) {
		$form['account']['mail']['#access'] = 0;
		$form['mimemail']['#access'] = 0;
	}
  }

  if ($form_id === 'link_node_form') {
	unset($form['field_banner_position']['und']['#options']['_none']);
  }

  if ($form_id === 'news_node_form') {
	unset($form['field_news_category']['und']['#options']['17641']);
  }

  if ($form_id === 'search_form') {
	$form['basic']['submit']['#value'] = 'Найти';
  }

  if ($form_id === 'page_node_form') {
	if (!in_array('administrator', $user->roles) and !in_array('moderator', $user->roles)) {
	  $form['menu']['enabled']['#disabled'] = 1;
	}
  }

}

?>